@@ -3,7 +3,7 @@
 # software; you can redistribute it and/or modify it under the same terms
 # as Perl itself.
 #
-# $Id: aegis-virus-scanner.pl,v 1.7 2004/09/20 11:13:56 jodrell Exp $
+# $Id: aegis-virus-scanner.pl,v 1.12 2004/12/14 16:07:01 jodrell Exp $
 use Gtk2 -init;
 use Gtk2::Helper;
 use Gtk2::GladeXML;
@@ -23,14 +23,14 @@ use strict;
 
 my $NAME		= 'Aegis';
 my $SNAME		= 'aegis-virus-scanner';
-our $VERSION		= '0.1.0';
+our $VERSION		= '0.1.1';
 my $LOGFILE		= sprintf('%s/%s.log', $ENV{HOME}, lc($NAME));
 my $QUARANTINE		= sprintf('%s/QUARANTINE', $ENV{HOME});
 my $RCFILE		= sprintf('%s/.%src', $ENV{HOME}, lc($NAME));
 my $PREFIX		= '@PREFIX@';
 my $GLADE_FILE		= (-d $PREFIX ? "$PREFIX/share/$SNAME"	: $ENV{PWD})."/$SNAME.glade";
 my $ICON_FILE		= (-d $PREFIX ? "$PREFIX/share/pixmaps"	: $ENV{PWD})."/$SNAME.png";
-my $LOCALE_DIR		= (-d $PREFIX ? "PREFIX/share/locale"	: $ENV{PWD}.'/locale');
+my $LOCALE_DIR		= (-d $PREFIX ? "$PREFIX/share/locale"	: $ENV{PWD}.'/locale');
 my $STOPPED		= 0;
 my $RUNNING		= 0;
 my $FM_URL		= 'http://freshmeat.net/projects-xml/filescan/filescan.xml';
@@ -275,7 +275,7 @@ sub on_about_button_clicked {
 		$ABOUT_DIALOG_TEXT,
 		_('{name} Virus Scanner version {version}', name => $NAME, version => $VERSION),
 		_('Author: Gavin Brown &lt;gavin.brown@uk.com&gt;'),
-		_('File::Scan last updated {age}', age => $AGE_STRING),
+		_('File::Scan {version}, last updated {age}', version => $File::Scan::VERSION, age => $AGE_STRING),
 	));
 	$app->get_widget('about_dialog')->show_all;
 }
@@ -383,7 +383,9 @@ sub scan_dir {
 		my (@files, @dirs);
 		foreach my $node (sort @nodes) {
 			next if ($node =~ /^\./ && !$app->get_widget('hidden_checkbutton')->get_active);
-			if (-d "$dir$node") {
+			if (-l "$dir$node") {
+				log_entry(_('{node} is a symbolic link, ignoring', node => "$dir$node"));
+			} elsif (-d "$dir$node") {
 				push(@dirs, $node);
 			} else {
 				push(@files, $node);
@@ -467,7 +469,11 @@ sub scan_archive {
 		chomp(my $tmpfile = sprintf('/tmp/%s-%s-%s', lc($NAME), (getpwuid($<))[0], encode_base64($file)));
 		extract_file_from_archive($archive, $file, $tmpfile);
 		my $virus = $scanner->scan($tmpfile);
-		unlink($tmpfile) or print STDERR "$tmpfile: $!\n";
+		my $cmd = sprintf('rm -rf "%s"', quotemeta($tmpfile));
+		system($cmd);
+		if ($? != 0) {
+			printf(STDERR "Error: command '%s' failed: returned error code %d\n", $cmd, $?);
+		}
 		return $virus if ($virus ne '');
 	}
 }
